from .common import BaseModel
from peewee import ForeignKeyField, TextField, DateField
from playhouse.sqlite_ext import JSONField


class Person(BaseModel):
    id = TextField(primary_key=True)
    name = TextField()
    given_name = TextField()
    family_name = TextField()
    gender = TextField()
    email = TextField()
    image = TextField()
    party = TextField()
    extras = JSONField()


class PersonLink(BaseModel):
    person = ForeignKeyField(Person, backref="links")
    url = TextField()
    note = TextField()


class PersonSource(BaseModel):
    person = ForeignKeyField(Person, backref="sources")
    url = TextField()
    note = TextField()


class PersonRole(BaseModel):
    person = ForeignKeyField(Person, backref="roles")
    start_date = DateField(null=True)
    end_date = DateField(null=True)
    type = TextField()
    jurisdiction = TextField()
    district = TextField()


class PersonOffice(BaseModel):
    person = ForeignKeyField(Person, backref="offices")
    classification = TextField()
    address = TextField()
    voice = TextField()
    fax = TextField()
